module Ruconomic
  module API
    module InvoiceLine
      extend Ruconomic::WebService

      def self.find_by_invoice_list(invoice_numbers)
        response = invoke('InvoiceLine_FindByInvoiceList') do |message|
          message.add 'invoiceHandles' do |handles|
            invoice_numbers.each do |invoice_number|
              handles.add 'InvoiceHandle' do |handle|
                handle.add 'Number', invoice_number
              end
            end
          end
        end

        result = response.to_hash.dig(
          :invoice_line_find_by_invoice_list_response,
          :invoice_line_find_by_invoice_list_result,
          :invoice_line_handle
        )

        case result
        when Array
          result
        when Hash
          [result]
        end
      end

      # Returns an invoice line data object for a given invoice line.
      # Parameters: entityHandle: A handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetData
      # @return [Hash] The body content of the SOAP response.
      def self.get_data
        response = invoke('InvoiceLine_GetData') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Returns invoice line data objects for a given set of invoice line handles.
      # Parameters: entityHandles: An array of the invoice line handles.
      #
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetDataArray
      # @return [Hash] The body content of the SOAP response.
      def self.get_data_array(invoice_line_handles)
        response = invoke('InvoiceLine_GetDataArray') do |message|
          message.add 'entityHandles' do |handles|
            invoice_line_handles.each do |invoice_line_handle|
              handles.add 'InvoiceLineHandle' do |handle|
                handle.add 'Id', invoice_line_handle.fetch(:id)
                handle.add 'Number', invoice_line_handle.fetch(:number)
              end
            end
          end
        end

        result = response.to_hash.dig(
          :invoice_line_get_data_array_response,
          :invoice_line_get_data_array_result,
          :invoice_line_data
        )

        case result
        when Array
          result
        when Hash
          [result]
        end
      end

      # Gets the number of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetNumber
      # @return [Hash] The body content of the SOAP response.
      def self.get_number
        response = invoke('InvoiceLine_GetNumber') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets a handle for the invoice of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetInvoice
      # @return [Hash] The body content of the SOAP response.
      def self.get_invoice
        response = invoke('InvoiceLine_GetInvoice') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets description of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetDescription
      # @return [Hash] The body content of the SOAP response.
      def self.get_description
        response = invoke('InvoiceLine_GetDescription') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets delivery date of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetDeliveryDate
      # @return [Hash] The body content of the SOAP response.
      def self.get_delivery_date
        response = invoke('InvoiceLine_GetDeliveryDate') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets a handle for the primary unit of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetUnit
      # @return [Hash] The body content of the SOAP response.
      def self.get_unit
        response = invoke('InvoiceLine_GetUnit') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets a handle for the product of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetProduct
      # @return [Hash] The body content of the SOAP response.
      def self.get_product
        response = invoke('InvoiceLine_GetProduct') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the primary quantity of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetQuantity
      # @return [Hash] The body content of the SOAP response.
      def self.get_quantity
        response = invoke('InvoiceLine_GetQuantity') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the price per unit without VAT of an invoice line (in the currency of the invoice).
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetUnitNetPrice
      # @return [Hash] The body content of the SOAP response.
      def self.get_unit_net_price
        response = invoke('InvoiceLine_GetUnitNetPrice') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the discount of an invoice line as percent.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetDiscountAsPercent
      # @return [Hash] The body content of the SOAP response.
      def self.get_discount_as_percent
        response = invoke('InvoiceLine_GetDiscountAsPercent') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the cost price per unit without VAT of an invoice line (in the default currency).
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetUnitCostPrice
      # @return [Hash] The body content of the SOAP response.
      def self.get_unit_cost_price
        response = invoke('InvoiceLine_GetUnitCostPrice') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the VAT rate of an invoice line.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetVatRate
      # @return [Hash] The body content of the SOAP response.
      def self.get_vat_rate
        response = invoke('InvoiceLine_GetVatRate') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the VAT amount of the invoice line (in the currency of the invoice).
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetVatAmount
      # @return [Hash] The body content of the SOAP response.
      def self.get_vat_amount
        response = invoke('InvoiceLine_GetVatAmount') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets the total amount of an invoice line without VAT (in the currency of the invoice).
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetTotalNetAmount
      # @return [Hash] The body content of the SOAP response.
      def self.get_total_net_amount
        response = invoke('InvoiceLine_GetTotalNetAmount') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets a handle for the department of an invoice line. The department is only accessible when there is access to the Dimension add-on module.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetDepartment
      # @return [Hash] The body content of the SOAP response.
      def self.get_department
        response = invoke('InvoiceLine_GetDepartment') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Gets a handle for the distribution key of an invoice line. The distribution key is only accessible when there is access to the Dimension add-on module.
      # Parameters: invoiceLineHandle: Handle for the invoice line.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_GetDistributionKey
      # @return [Hash] The body content of the SOAP response.
      def self.get_distribution_key
        response = invoke('InvoiceLine_GetDistributionKey') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Returns handles for invoice lines that uses a given product.
      # Parameters: product: The product to search for.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_FindByProduct
      # @return [Hash] The body content of the SOAP response.
      def self.find_by_product
        response = invoke('InvoiceLine_FindByProduct') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Returns handles for invoice lines that uses a given set of products.
      # Parameters: products: The products to search for.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_FindByProductList
      # @return [Hash] The body content of the SOAP response.
      def self.find_by_product_list
        response = invoke('InvoiceLine_FindByProductList') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

      # Returns handles for invoice lines for a given invoice number interval.
      # Parameters: fromInvoiceNumber: The minimum invoice number to search for. toInvoiceNumber: The maximum invoice number to search for.
      #
      # @note TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
      # @see https://api.e-conomic.com/secure/api1/EconomicWebService.asmx?op=InvoiceLine_FindByInvoiceNumberInterval
      # @return [Hash] The body content of the SOAP response.
      def self.find_by_invoice_number_interval
        response = invoke('InvoiceLine_FindByInvoiceNumberInterval') do |message|
          raise "TODO: This method was autogenerated from the WSDL - see https://github.com/coherify/ruconomic#contributing"
        end
      end

    end
  end
end
